==> Cosmos7.641.tar.gz: Cosmos7.641/cosmos/Znamelist2.h <==
c         This namelist data may be given only some
c         special purpose such as to see the scattering effect
c         by putting  Es = 0.

       namelist  /HParam/
     +  AnihiE, AtEnv, AtmosFile, BackAngLimit, BaseErg, BasePower
     +, BorderHeightH, BorderHeightL, Cekaon, Ceneuc, Cepic0
     +, Charge2heavyG, Code2heavyG, Code2massN, DefofR
     +, Deltkp, Deltpip, Deltpp
     +, DoNPadjust, dpmRareDecay
     +, DpmFile, Ecrit, Efermi, Elund, Elund2, Elund3, EndLevel
     +, EndLevel2, ErrorOut, Es, Eta2Pi0, EthinRatio, EventNo
     +, EventsInTheRun, ExactThick, FragmentTbl, Generate2
     +, GeomagFile
     +, HeavyG2charge, HeavyG2code, HeavyG2massN, HeavyG2symbol
     +, HowGeomag, HowIntNuc, HowEfield,  HowPhotoP, ASRforDPM
     +, InclusiveFile, IncreaseXsec, KEminObs2
     +, KnockOnRatio, Knockon, Kpicns, Kpilog, LamorDiv, LpmBremEmin
     +, LpmPairEmin, LundPara, MagBrem, MagBremEmin, MagChgDist, MagD
     +, MagE, MagN, MagPair, MagPairEmin, MaxComptonE, MaxPhotoE
     +, Excom1, Excom2,  Eabsorb 
     +, Moliere, MuBr, MuNI, MuPr, Mudirp, MulLow, myEf, NoOfSites2
     +, OffsetHeight, PathLimit, PercentEnv, PrevEventNo, PtAvFrag
     +, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse
     +, SeedFileDev
     +, SharpEnv, StepControl,SucInt, SucPw, TempDev, TotXSopt
     +, TraceDev,  Truncc, Truncn
     +, Truncx, UpsilonMin, UseRungeKutta, UserHookc, UserHooki
     +, UserHookr, X0, XaxisFromSouth, SxAbySxpOpt
     +, PhitsXs, JamXs,  AAXsec, JamFragment

==> Cosmos7.645.tar.gz: Cosmos7.645/cosmos/Znamelist2.h <==
c         This namelist data may be given only some
c         special purpose such as to see the scattering effect
c         by putting  Es = 0.

       namelist  /HParam/
     +  AnihiE, AtEnv, AtmosFile, BackAngLimit, BaseErg, BasePower
     +, BorderHeightH, BorderHeightL, Cekaon, Ceneuc, Cepic0
     +, Charge2heavyG, Code2heavyG, Code2massN, DefofR
     +, Deltkp, Deltpip, Deltpp
     +, DoNPadjust, dpmRareDecay
     +, DpmFile, Ecrit, Efermi, Elund, Elund2, Elund3, EndLevel
     +, EndLevel2, ErrorOut, Es, Eta2Pi0, EthinRatio, EventNo
     +, EventsInTheRun, ExactThick, FragmentTbl, Generate2
     +, GeomagFile
     +, HeavyG2charge, HeavyG2code, HeavyG2massN, HeavyG2symbol
     +, HowGeomag, HowIntNuc, HowEfield,  HowPhotoP, ASRforDPM
     +, InclusiveFile, IncreaseXsec, KEminObs2
     +, KnockOnRatio, Knockon, Kpicns, Kpilog, LamorDiv, LpmBremEmin
     +, LpmPairEmin, LundPara, MagBrem, MagBremEmin, MagChgDist, MagD
     +, MagE, MagN, MagPair, MagPairEmin, MaxComptonE, MaxPhotoE
     +, Excom1, Excom2,  Eabsorb 
     +, Moliere, MuBr, MuNI, MuPr, Mudirp, MulLow, myEf
     +, NoOfSites2, NRL_period 
     +, OffsetHeight, PathLimit, PercentEnv, PrevEventNo, PtAvFrag
     +, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse
     +, SeedFileDev
     +, SharpEnv, StepControl,SucInt, SucPw, TempDev, TotXSopt
     +, TraceDev,  Truncc, Truncn
     +, Truncx, UpsilonMin, UseRungeKutta, UserHookc, UserHooki
     +, UserHookr, X0, XaxisFromSouth, SxAbySxpOpt
     +, PhitsXs, JamXs,  AAXsec, JamFragment
